from distutils.core import setup
setup(
  name = 'wthen',
  packages = ['wthen'], # this must be the same as the name above
  version = '0.1.2',
  description = 'A simple rule engine with YAML format',
  author = 'Alex Yu',
  author_email = 'mltest2000@aliyun.com',
  url = 'https://github.com/sevenbigcat/wthen', # use the URL to the github repo
  download_url = 'https://github.com/sevenbigcat/wtehn/archive/0.1.tar.gz', # I'll explain this in a second
  keywords = ['rule engine', 'ECA', 'YAML'], # arbitrary keywords
  classifiers = [],
)
